aboutsummaryrefslogtreecommitdiffstats
path: root/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc
diff options
context:
space:
mode:
authorramverma <ram.krishna.verma@ericsson.com>2018-08-23 13:50:31 +0100
committerramverma <ram.krishna.verma@ericsson.com>2018-08-24 10:04:31 +0100
commitef2ff6bae65870a4fccc25373c0cfae881e14a81 (patch)
tree2329de6759a3f74237b8a64dcbe63d7114f532ef /plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc
parent55e6bdc93d05f1c9673a4ecbe133207722216eb0 (diff)
Fix sonar and checkstyle issues in distribution
* Fixing all check style issues. * Fixing all sonar issues. * Adding maven check style plugin to fail at warning level. Change-Id: I791b8feef39a3a0c3e1e250efea7b6e78208bf07 Issue-ID: POLICY-1035 Signed-off-by: ramverma <ram.krishna.verma@ericsson.com>
Diffstat (limited to 'plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc')
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/PssdConfiguration.java (renamed from plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/PSSDConfiguration.java)8
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdControllerException.java (renamed from plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDControllerException.java)12
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdDownloadException.java (renamed from plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDDownloadException.java)12
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdParametersException.java (renamed from plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDParametersException.java)12
4 files changed, 22 insertions, 22 deletions
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/PSSDConfiguration.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/PssdConfiguration.java
index baba4d42..c5c877e1 100644
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/PSSDConfiguration.java
+++ b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/PssdConfiguration.java
@@ -23,25 +23,25 @@ package org.onap.policy.distribution.reception.handling.sdc;
import java.util.List;
import org.onap.sdc.api.consumer.IConfiguration;
-import org.onap.policy.distribution.reception.parameters.PSSDConfigurationParametersGroup;
+import org.onap.policy.distribution.reception.parameters.PssdConfigurationParametersGroup;
/**
* Properties for the handling Sdc
*
*/
-public class PSSDConfiguration implements IConfiguration {
+public class PssdConfiguration implements IConfiguration {
// Configuration file structure
// Configuration file properties
- private PSSDConfigurationParametersGroup configParameters = null;
+ private PssdConfigurationParametersGroup configParameters = null;
/**
* Original constructor
*
* @param configParameters properties needed to be configured for the model loader
*/
- public PSSDConfiguration(final PSSDConfigurationParametersGroup configParameters) {
+ public PssdConfiguration(final PssdConfigurationParametersGroup configParameters) {
this.configParameters = configParameters;
}
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDControllerException.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdControllerException.java
index ff9acfd0..9dece808 100644
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDControllerException.java
+++ b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdControllerException.java
@@ -22,9 +22,9 @@ package org.onap.policy.distribution.reception.handling.sdc.exceptions;
/**
- * Exception of the PSSD controller.
+ * Exception of the Pssd controller.
*/
-public class PSSDControllerException extends Exception {
+public class PssdControllerException extends Exception {
/**
* serialization id.
@@ -32,22 +32,22 @@ public class PSSDControllerException extends Exception {
private static final long serialVersionUID = -8507246953751956974L;
/**
* Constructor for creating PSSDControllerException using message.
*
* @param message The message to dump
*/
- public PSSDControllerException (final String message) {
+ public PssdControllerException (final String message) {
super (message);
}
/**
* Constructor for creating PSSDControllerException using message and exception.
*
* @param message The message to dump
* @param e the exception that caused this exception to be thrown
*/
- public PSSDControllerException (final String message, final Exception e) {
+ public PssdControllerException (final String message, final Exception e) {
super (message, e);
}
@@ -32,22 +32,22 @@ public class PSSDControllerException extends Exception {
private static final long serialVersionUID = -8507246953751956974L;
/**
- * Constructor for creating PSSDControllerException using message.
+ * Constructor for creating PssdControllerException using message.
*
* @param message The message to dump
@@ -32,22 +32,22 @@ public class PSSDControllerException extends Exception {
}
/**
- * Constructor for creating PSSDControllerException using message and exception.
+ * Constructor for creating PssdControllerException using message and exception.
*
* @param message The message to dump
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDDownloadException.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdDownloadException.java
index f95179c1..14c6b5ea 100644
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDDownloadException.java
+++ b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdDownloadException.java
@@ -22,9 +22,9 @@ package org.onap.policy.distribution.reception.handling.sdc.exceptions;
/**
- * Exception during download from PSSD.
+ * Exception during download from Pssd.
*/
-public class PSSDDownloadException extends Exception {
+public class PssdDownloadException extends Exception {
/**
* serialization id.
@@ -32,22 +32,22 @@ public class PSSDDownloadException extends Exception {
private static final long serialVersionUID = -8507246953751956974L;
/**
* Constructor for creating PSSDDownloadException using message.
*
* @param message The message to dump
*/
- public PSSDDownloadException (final String message) {
+ public PssdDownloadException (final String message) {
super (message);
}
/**
* Constructor for creating PSSDDownloadException using message and exception.
*
* @param message The message to dump
* @param e the exception that caused this exception to be thrown
*/
- public PSSDDownloadException (final String message, final Exception e) {
+ public PssdDownloadException (final String message, final Exception e) {
super (message, e);
}
@@ -32,22 +32,22 @@ public class PSSDDownloadException extends Exception {
private static final long serialVersionUID = -8507246953751956974L;
/**
- * Constructor for creating PSSDDownloadException using message.
+ * Constructor for creating PssdDownloadException using message.
*
* @param message The message to dump
@@ -32,22 +32,22 @@ public class PSSDDownloadException extends Exception {
}
/**
- * Constructor for creating PSSDDownloadException using message and exception.
+ * Constructor for creating PssdDownloadException using message and exception.
*
* @param message The message to dump
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDParametersException.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdParametersException.java
index 91922d7d..ca17796c 100644
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDParametersException.java
+++ b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdParametersException.java
@@ -22,9 +22,9 @@ package org.onap.policy.distribution.reception.handling.sdc.exceptions;
/**
- * Exception of the PSSD controller.
+ * Exception of the Pssd controller.
*/
-public class PSSDParametersException extends Exception {
+public class PssdParametersException extends Exception {
/**
* serialization id.
@@ -32,22 +32,22 @@ public class PSSDParametersException extends Exception {
private static final long serialVersionUID = -8507246953751956974L;
/**
* Constructor for creating PSSDParametersException using message.
*
* @param message The message to dump
*/
- public PSSDParametersException (final String message) {
+ public PssdParametersException (final String message) {
super (message);
}
/**
* Constructor for creating PSSDParametersException using message and exception.
*
* @param message The message to dump
* @param e the exception that caused this exception to be thrown
*/
- public PSSDParametersException (final String message, final Exception e) {
+ public PssdParametersException (final String message, final Exception e) {
super (message, e);
}
@@ -32,22 +32,22 @@ public class PSSDParametersException extends Exception {
private static final long serialVersionUID = -8507246953751956974L;
/**
- * Constructor for creating PSSDParametersException using message.
+ * Constructor for creating PssdParametersException using message.
*
* @param message The message to dump
@@ -32,22 +32,22 @@ public class PSSDParametersException extends Exception {
}
/**
- * Constructor for creating PSSDParametersException using message and exception.
+ * Constructor for creating PssdParametersException using message and exception.
*
* @param message The message to dump